Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is an adapter for the Docker Engine API client to our domain.
func (*Client) FetchContainerLogs ¶
FetchContainerLogs returns a filtered stream of logs from the specified Docker container. If the container cannot be found it returns a *log.Error.
func (*Client) ListContainers ¶
ListContainers fetches the list of all containers in Docker (docker ps -a).
Click to show internal directories.
Click to hide internal directories.